@@ -26,10 +26,11 @@ const char *cCriteria::GetChannelName() const {
 bool cCriteria::GoodVPS() {
     if (!channelName) return false;
 
-    if (CompareChannelName(channelName, "arte",         IGNORE_HD))               return true;
+//    if (CompareChannelName(channelName, "arte",         IGNORE_HD))               return true;    // VPS start event before preview
     if (CompareChannelName(channelName, "Das_Erste",    IGNORE_HD))               return true;
     if (CompareChannelName(channelName, "hr-fernsehen", IGNORE_HD))               return true;
     if (CompareChannelName(channelName, "KiKA",         IGNORE_HD))               return true;
+    if (CompareChannelName(channelName, "MDR",          IGNORE_HD | IGNORE_CITY)) return true;
     if (CompareChannelName(channelName, "NDR_FS",       IGNORE_HD | IGNORE_CITY)) return true;
     if (CompareChannelName(channelName, "rbb",          IGNORE_HD | IGNORE_CITY)) return true;
     if (CompareChannelName(channelName, "SR_Fernsehen", IGNORE_HD))               return true;
@@ -58,9 +59,11 @@ int cCriteria::LogoFadeInOut() {
     if (CompareChannelName(channelName, "NICK_MTV+",      IGNORE_HD))                  return FADE_IN | FADE_OUT;
     if (CompareChannelName(channelName, "NRJ12",          IGNORE_NOTHING))             return FADE_IN;
     if (CompareChannelName(channelName, "Pro7_MAXX",      IGNORE_HD))                  return FADE_IN;
+    if (CompareChannelName(channelName, "ProSieben",      IGNORE_HD))                  return FADE_IN;   // delaed logo start, short fade in
     if (CompareChannelName(channelName, "ProSieben_MAXX", IGNORE_HD))                  return FADE_IN;
     if (CompareChannelName(channelName, "RTLNITRO",       IGNORE_HD))                  return FADE_IN;
     if (CompareChannelName(channelName, "RTLZWEI",        IGNORE_HD))                  return FADE_IN;
+    if (CompareChannelName(channelName, "SAT_1_Gold",     IGNORE_HD | IGNORE_COUNTRY)) return FADE_IN;
     if (CompareChannelName(channelName, "ServusTV",       IGNORE_HD))                  return FADE_OUT;
     if (CompareChannelName(channelName, "sixx",           IGNORE_HD))                  return FADE_IN;
     if (CompareChannelName(channelName, "SUPER_RTL",      IGNORE_HD))                  return FADE_OUT;
@@ -134,6 +137,7 @@ bool cCriteria::InfoInBorder() {   // info logo or closing banner in one of the
 }
 
 
+// logo change color during broadcast
 bool cCriteria::LogoColorChange() {
     if (!channelName) return false;
     if (CompareChannelName(channelName, "Disney_Channel", IGNORE_HD))                  return true;
@@ -141,6 +145,7 @@ bool cCriteria::LogoColorChange() {
     if (CompareChannelName(channelName, "FOX_Channel",    IGNORE_HD))                  return true;   // changes from white to red at recording start
     if (CompareChannelName(channelName, "kabel_eins",     IGNORE_HD))                  return true;
     if (CompareChannelName(channelName, "NRJ12",          IGNORE_NOTHING))             return true;
+    if (CompareChannelName(channelName, "RTL_Television", IGNORE_HD | IGNORE_COUNTRY)) return true;
     if (CompareChannelName(channelName, "TELE_5",         IGNORE_HD))                  return true;
     return false;
 }
